Index: app/mac/nsimage_cache.h |
=================================================================== |
--- app/mac/nsimage_cache.h (revision 69953) |
+++ app/mac/nsimage_cache.h (working copy) |
@@ -1,9 +1,9 @@ |
-// Copyright (c) 2009 The Chromium Authors. All rights reserved. |
+// Copyright (c) 2010 The Chromium Authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef BASE_NSIMAGE_CACHE_MAC_H_ |
-#define BASE_NSIMAGE_CACHE_MAC_H_ |
+#ifndef APP_MAC_NSIMAGE_CACHE_H_ |
+#define APP_MAC_NSIMAGE_CACHE_H_ |
#pragma once |
#ifdef __OBJC__ |
@@ -14,7 +14,8 @@ |
class NSString; |
#endif |
-namespace nsimage_cache { |
+namespace app { |
+namespace mac { |
// Returns an autoreleased image from the main app bundle |
// (mac_util::MainAppBundle()) with the given name, and keeps it in memory so |
@@ -23,11 +24,12 @@ |
// - This should only be called on the main thread. |
// - The caller should retain the image if they want to keep it around, as |
// the cache could have limit on size/lifetime, etc. |
-NSImage* ImageNamed(NSString* name); |
+NSImage* GetCachedImageWithName(NSString* name); |
-// Clears the cache. |
-void Clear(void); |
+// Clears the image cache. |
+void ClearCachedImages(void); |
-} // namespace nsimage_cache |
+} // namespace mac |
+} // namespace app |
-#endif // BASE_NSIMAGE_CACHE_MAC_H_ |
+#endif // APP_MAC_NSIMAGE_CACHE_H_ |